Looking at https://integration.wikimedia.org/ci/job/quibble-for-mediawiki-core-browser-tests-only-vendor-mysql-php83/5642/console it seems like we run npm install twice for mediawiki/core:
npm install in /workspace/src 00:01:07.806 DEBUG:quibble.util:Waiting for Post-dependency install, pre-database dependent steps: 20s elapsed, 1/2 completed 00:01:10.135 INFO:quibble.commands:>>> Start: npm install in /workspace/src ...00:01:10.136 added 1718 packages, and audited 1720 packages in 22s ... 00:01:10.140 * npm install in /workspace/src, in 22.366 s
And then another time:
00:01:10.153 INFO:quibble.commands:>>> Start: Browser tests: mediawiki/core, mediawiki/skins/Vector, mediawiki/vendor 00:01:33.047 added 1718 packages, and audited 1720 packages in 23s
I wonder if it's a bug or a feature? Maybe there could be a way to avoid it and speed up the core job by 20 seconds?